@@ -12,12 +12,14 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-_defaults = dict(
-    auth_type='password',
-    compute_api_version='2',
-    identity_api_version='2',
-    image_api_version='1',
-    network_api_version='2',
-    object_api_version='1',
-    volume_api_version='1',
+import os
+
+from openstack.config import defaults
+
+_json_path = os.path.join(
+    os.path.dirname(os.path.realpath(__file__)), 'defaults.json'
 )
+
+
+def get_defaults():
+    return defaults.get_defaults(json_path=_json_path)
